package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.FoodIngredients;
import com.yunzhi.inte.service.FoodIngredientsService;

/**
 * 菜肴食材;(food_ingredients)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "菜肴食材对象功能接口")
@RestController
@RequestMapping("/")
public class FoodIngredientsController extends BaseController {

    @Autowired
    private FoodIngredientsService foodIngredientsService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/foodIngredients/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(foodIngredientsService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/foodIngredients")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {

        IPage<FoodIngredients> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<FoodIngredients> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<FoodIngredients> result = foodIngredientsService.page(pg);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param foodIngredients 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/foodIngredients")
    public ResponseBean add(FoodIngredients foodIngredients) throws Exception {
        foodIngredientsService.save(foodIngredients);
        return ResponseBean.success(foodIngredients);
    }

    /**
     * 更新数据
     *
     * @param foodIngredients 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/foodIngredients/{id}")
    public ResponseBean edit(FoodIngredients foodIngredients) throws Exception {
        foodIngredientsService.updateById(foodIngredients);
        return ResponseBean.success(foodIngredients);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/foodIngredients/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        foodIngredientsService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}