package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.GuaranteeDetail;
import com.yunzhi.inte.service.GuaranteeDetailService;

/**
 * 保障详情;(guarantee_detail)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "保障详情对象功能接口")
@RestController
@RequestMapping("/")
public class GuaranteeDetailController extends BaseController {

    @Autowired
    private GuaranteeDetailService guaranteeDetailService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/guaranteeDetail/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(guaranteeDetailService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/guaranteeDetail")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {

        IPage<GuaranteeDetail> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<GuaranteeDetail> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<GuaranteeDetail> result = guaranteeDetailService.page(pg);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param guaranteeDetail 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/guaranteeDetail")
    public ResponseBean add(GuaranteeDetail guaranteeDetail) throws Exception {
        guaranteeDetailService.save(guaranteeDetail);
        return ResponseBean.success(guaranteeDetail);
    }

    /**
     * 更新数据
     *
     * @param guaranteeDetail 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/guaranteeDetail/{id}")
    public ResponseBean edit(GuaranteeDetail guaranteeDetail) throws Exception {
        guaranteeDetailService.updateById(guaranteeDetail);
        return ResponseBean.success(guaranteeDetail);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/guaranteeDetail/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        guaranteeDetailService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}