package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.GuaranteeTask;
import com.yunzhi.inte.service.GuaranteeTaskService;

/**
 * 供给保障;(guarantee_task)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "供给保障对象功能接口")
@RestController
@RequestMapping("/")
public class GuaranteeTaskController extends BaseController {

    @Autowired
    private GuaranteeTaskService guaranteeTaskService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/guaranteeTask/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(guaranteeTaskService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/guaranteeTask")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {

        IPage<GuaranteeTask> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<GuaranteeTask> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<GuaranteeTask> result = guaranteeTaskService.page(pg);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param guaranteeTask 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/guaranteeTask")
    public ResponseBean add(GuaranteeTask guaranteeTask) throws Exception {
        guaranteeTaskService.save(guaranteeTask);
        return ResponseBean.success(guaranteeTask);
    }

    /**
     * 更新数据
     *
     * @param guaranteeTask 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/guaranteeTask/{id}")
    public ResponseBean edit(GuaranteeTask guaranteeTask) throws Exception {
        guaranteeTaskService.updateById(guaranteeTask);
        return ResponseBean.success(guaranteeTask);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/guaranteeTask/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        guaranteeTaskService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}