package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Store;
import com.yunzhi.inte.service.StoreService;

/**
 * 库存表;(store)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "库存表对象功能接口")
@RestController
@RequestMapping("/")
public class StoreController extends BaseController {

    @Autowired
    private StoreService storeService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/store/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(storeService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/store")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {

        IPage<Store> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<Store> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<Store> result = storeService.page(pg);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param store 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/store")
    public ResponseBean add(Store store) throws Exception {
        storeService.save(store);
        return ResponseBean.success(store);
    }

    /**
     * 更新数据
     *
     * @param store 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/store/{id}")
    public ResponseBean edit(Store store) throws Exception {
        storeService.updateById(store);
        return ResponseBean.success(store);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/store/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        storeService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}