package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.StoreLog;
import com.yunzhi.inte.service.StoreLogService;

/**
 * 库存日志;(store_log)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "库存日志对象功能接口")
@RestController
@RequestMapping("/")
public class StoreLogController extends BaseController {

    @Autowired
    private StoreLogService storeLogService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/storeLog/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(storeLogService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/storeLog")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {

        IPage<StoreLog> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<StoreLog> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<StoreLog> result = storeLogService.page(pg);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param storeLog 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/storeLog")
    public ResponseBean add(StoreLog storeLog) throws Exception {
        storeLogService.save(storeLog);
        return ResponseBean.success(storeLog);
    }

    /**
     * 更新数据
     *
     * @param storeLog 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/storeLog/{id}")
    public ResponseBean edit(StoreLog storeLog) throws Exception {
        storeLogService.updateById(storeLog);
        return ResponseBean.success(storeLog);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/storeLog/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        storeLogService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}