package com.yunzhi.inte.rtsp;

import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.Channel;
import io.netty.channel.EventLoopGroup;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;

/**
 * 引导服务器
 */
@Slf4j
@Component
public class MonitorServer extends Thread {
    @Value("${my.minitor.port}")
    Integer port;

    @Autowired
    FFmpeg fFmpeg;

    public void run() {
        TransferRtspHelper.TransferTask.fFmpeg = fFmpeg;
        EventLoopGroup group = new NioEventLoopGroup();
        EventLoopGroup workerGroup = new NioEventLoopGroup();

        ServerBootstrap bootstrap = new ServerBootstrap();
        bootstrap.group(group, workerGroup).channel(NioServerSocketChannel.class)
                .childHandler(new MonitorServerInitializer());

        try {
            Channel channel = bootstrap.bind(port).sync().channel();

            TransferRtspHelper.schedule();
            log.info("服务器开始运行......[:{}]", port);

            channel.closeFuture().sync();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }

        Runtime.getRuntime().addShutdownHook(new Thread(() -> {
            group.shutdownGracefully();
            workerGroup.shutdownGracefully();
            ChannelGroupHolder.close();
            log.info("服务器已关闭");
        }));
    }
}
